# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['PyInquirer', 'PyInquirer.prompts']

package_data = \
{'': ['*']}

install_requires = \
['prompt-toolkit>=3.0.41,<4.0.0', 'pygments>=2.17.2,<3.0.0']

setup_kwargs = {
    'name': 'py-inquirer-cli',
    'version': '0.0.1',
    'description': 'A Python module for collection of common interactive command line user interfaces, based on Inquirer.js',
    'long_description': 'PythonInquirer\n==============\n.. image:: https://opencollective.com/pyinquirer/backers/badge.svg\n    :alt: Backers on Open Collective\n    :target: #backers\n\n.. image:: https://opencollective.com/pyinquirer/sponsors/badge.svg\n    :alt: Sponsors on Open Collective\n    :target: #sponsors\n\n.. image:: https://travis-ci.org/expobrain/PyInquirer.svg?branch=master\n    :target: https://travis-ci.org/expobrain/PyInquirer\n\n\n**Update: We are looking for a successor/maintainance. Here: <https://github.com/CITGuru/PyInquirer/issues/159>**\n**Github is starting to invite developers in from the GitHub Sponsors waitlist!**\n\nYour recommendations matter, so be sure to nominate `me and other contributors <https://github.com/CITGuru/PyInquirer/graphs/contributors>`__ of this project you\'d like to see on GitHub Sponsors next by using the form in this link: http://github.co/2IHdeOw\n\n\nPyInquirer is a collection of common interactive command line user interfaces. \n\n\nPyInquirer 1.0.3 Bugfix Update\n------------------------------\n\n`PyInquirer 1.0.3 <https://github.com/CITGuru/PyInquirer/releases/tag/1.0.3>`\n\n\nTable of Contents\n-----------------\n\n1. `Documentation <#documentation>`__\n\n   1. `Installation <#installation>`__\n   2. `Examples <#examples>`__\n   3. `Quickstart <#quickstart>`__\n   4. `Question Types <#types>`__\n   5. `Question Properties <#properties>`__\n   6. `User Interfaces and Styles <#styles>`__\n\n2. `Windows Platform <#windows>`__\n3. `Support <#support>`__\n4. `Contribution <#contribution>`__\n5. `Acknowledgments <#acknowledgements>`__\n6. `License <#license>`__\n\nGoal and Philosophy\n-------------------\n\n**PyInquirer** strives to be an easily embeddable and beautiful\ncommand line interface for `Python <https://python.org/>`__.\n**PyInquirer** wants to make it easy for existing Inquirer.js users\nto write immersive command line applications in Python. We are convinced\nthat its feature-set is the most complete for building immersive CLI\napplications. We also hope that **PyInquirer** proves itself useful\nto Python users.\n\n**PyInquirer** should ease the process of - providing *error\nfeedback* - *asking questions* - *parsing* input - *validating* answers\n- managing *hierarchical prompts*\n\n**Note:** **PyInquirer** provides the user interface and the inquiry\nsession flow. >\n\nDocumentation\n-------------\n\nInstallation\n~~~~~~~~~~~~\n\nLike most Python packages PyInquirer is available on `PyPi <https://pypi.org/project/PyInquirer/>`__.\nSimply use pip to install the PyInquirer package\n\n.. code:: shell\n\n    pip install PyInquirer\n\nIn case you encounter any prompt\\_toolkit error, that means you\'ve the\nwrong prompt\\_toolkit version.\n\nYou can correct that by doing\n\n.. code:: shell\n\n    pip install prompt_toolkit==1.0.14\n\nor download the wheel file from here:\n\n.. code:: shell\n\n    https://pypi.org/project/prompt_toolkit/1.0.14/#files\n\nQuickstart\n~~~~~~~~~~\n\nLike Inquirer.js, using inquirer is structured into two simple steps:\n\n-  you define a **list of questions** and hand them to **prompt**\n-  prompt returns a **list of answers**\n\n.. code:: python\n\n    from __future__ import print_function, unicode_literals\n    from PyInquirer import prompt, print_json\n\n    questions = [\n        {\n            \'type\': \'input\',\n            \'name\': \'first_name\',\n            \'message\': \'What\\\'s your first name\',\n        }\n    ]\n\n    answers = prompt(questions)\n    print_json(answers)  # use the answers as input for your app\n\nA good starting point from here is probably the examples section.\n\nExamples\n~~~~~~~~\n\nMost of the examples intend to demonstrate a single question type or\nfeature:\n\n-  `editor.py <./examples/editor.py>`_\n-  `expand.py <./examples/expand.py>`_\n-  `list.py <./examples/list.py>`_\n-  `password.py <./examples/password.py>`_\n-  `when.py <./examples/when.py>`_\n-  `checkbox.py <./examples/checkbox.py>`_\n-  `confirm.py <./examples/confirm.py>`_\n-  `hierarchical.py <./examples/hierarchical.py>`_\n-  `pizza.py <./examples/pizza.py>`_ - demonstrate using different question types\n-  `input.py  <./examples/input.py>`_\n-  `rawlist.py <./examples/rawlist.py>`_\n\nIf you want to launch examples with the code from repository instead of\ninstalling a package you need to execute ``pip install -e .`` within project\ndirectory.\n\nQuestion Types\n~~~~~~~~~~~~~~\n\n``questions`` is a list of questions. Each question has a type.\n\nList - ``{type: \'list\'}``\n^^^^^^^^^^^^^^^^^^^^^^^^^\n\nTake ``type``, ``name``, ``message``, ``choices``\\ [, ``default``,\n``filter``] properties. (Note that default must be the choice ``index``\nin the array or a choice ``value``)\n\n|List prompt| s ---\n\nRaw List - ``{type: \'rawlist\'}``\n^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\n\nTake ``type``, ``name``, ``message``, ``choices``\\ [, ``default``,\n``filter``] properties. (Note that default must the choice ``index`` in\nthe array)\n\n.. figure:: https://raw.githubusercontent.com/citguru/PyInquirer/master/docs/images/raw-list.png\n   :alt: Raw list prompt\n\n   Raw list prompt\n\n--------------\n\nExpand - ``{type: \'expand\'}``\n^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\n\nTake ``type``, ``name``, ``message``, ``choices``\\ [, ``default``]\nproperties. (Note that default must be the choice ``index`` in the\narray. If ``default`` key not provided, then ``help`` will be used as\ndefault choice)\n\nNote that the ``choices`` object will take an extra parameter called\n``key`` for the ``expand`` prompt. This parameter must be a single\n(lowercased) character. The ``h`` option is added by the prompt and\nshouldn\'t be defined by the user.\n\nSee ``examples/expand.py`` for a running example.\n\n|Expand prompt closed| |Expand prompt expanded|\n\n--------------\n\nCheckbox - ``{type: \'checkbox\'}``\n^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\n\nTake ``type``, ``name``, ``message``, ``choices``\\ [, ``filter``,\n``validate``] properties.\n\nChoices marked as ``{\'checked\': True}`` will be checked by default.\n\nChoices whose property ``disabled`` is truthy will be unselectable. If\n``disabled`` is a string, then the string will be outputted next to the\ndisabled choice, otherwise it\'ll default to ``"Disabled"``. The\n``disabled`` property can also be a synchronous function receiving the\ncurrent answers as argument and returning a boolean or a string.\n\nThe ``pointer_index`` kwarg can be used to specify initial pointer position.\n\n.. figure:: https://raw.githubusercontent.com/citguru/PyInquirer/master/docs/images/checkbox-prompt.png\n   :alt: Checkbox prompt\n\n   Checkbox prompt\n\n--------------\n\nConfirm - ``{type: \'confirm\'}``\n^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\n\nTake ``type``, ``name``, ``message``\\ [, ``default``] properties.\n``default`` is expected to be a boolean if used.\n\n.. figure:: https://raw.githubusercontent.com/citguru/PyInquirer/master/docs/images/confirm-prompt.png\n   :alt: Confirm prompt\n\n   Confirm prompt\n\n--------------\n\nInput - ``{type: \'input\'}``\n^^^^^^^^^^^^^^^^^^^^^^^^^^^\n\nTake ``type``, ``name``, ``message``\\ [, ``default``, ``filter``,\n``validate``] properties.\n\n.. figure:: https://raw.githubusercontent.com/citguru/PyInquirer/master/docs/images/input-prompt.png\n   :alt: Input prompt\n\n   Input prompt\n\n--------------\n\nPassword - ``{type: \'password\'}``\n^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\n\nTake ``type``, ``name``, ``message``\\ [, ``default``, ``filter``,\n``validate``] properties.\n\n.. figure:: https://raw.githubusercontent.com/citguru/PyInquirer/master/docs/images/password-prompt.png\n   :alt: Password prompt\n\n   Password prompt\n\n--------------\n\nEditor - ``{type: \'editor\'}``\n^^^^^^^^^^^^^^^^^^^^^^^^^^^^^\n\nTake ``type``, ``name``, ``message``\\ [, ``default``, ``filter``,\n``validate``, ``eargs``] properties\n\nEditor Arguments - ``eargs``\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\nOpens an empty or edits the default text in the defined editor.  If an editor is given\n(should be the full path to the executable but the regular operating\nsystem search path is used for finding the executable) it overrides\nthe detected editor.  Optionally, some environment variables can be\nused.  If the editor is closed without changes, ``None`` is returned.  In\ncase a file is edited directly the return value is always ``None`` and\n``save`` and ``ext`` are ignored.\n\nTakes:\n\n-  editor: accepts ``default`` to get the default platform editor. But\n   you can also provide the path to an editor e.g ``vi``.\n-  ext: the extension to tell the editor about. This defaults to `.txt`\n   but changing this might change syntax highlighting e.g ".py"\n-  save: accepts ``True`` or ``False`` to determine to save a file.\n-  filename: accepts the path of a file you\'d like to edit.\n-  env: accepts any given environment variables to pass to the editor\n\nLaunches an instance of the users preferred editor on a temporary file.\nOnce the user exits their editor, the contents of the temporary file are\nread in as the result. The editor to use is determined by reading the\nVISUAL or EDITOR environment variables. If neither of those\nare present, notepad (on Windows) or vim (Linux or Mac) is used.\n\nQuestion Properties\n~~~~~~~~~~~~~~~~~~~\n\nA question is a dictionary containing question related values:\n\n-  ``type``: (String) Type of the prompt. Defaults: input - Possible values:\n   input, confirm, list, rawlist, expand, checkbox, password, editor\n-  ``name``: (String) The name to use when storing the answer in the answers\n   hash. If the name contains periods, it will define a path in the\n   answers hash.\n-  ``message``: (String\\|Function) The question to print. If defined as a\n   function, the first parameter will be the current inquirer session\n   answers.\n-  ``default``: (String\\|Number\\|Array\\|Function) Default value(s) to use if\n   nothing is entered, or a function that returns the default value(s).\n   If defined as a function, the first parameter will be the current\n   inquirer session answers.\n-  ``choices``: (Array\\|Function) Choices array or a function returning a\n   choices array. If defined as a function, the first parameter will be\n   the current inquirer session answers. Array values can be simple\n   strings, or objects containing a name (to display in list), a value\n   (to save in the answers hash) and a short (to display after\n   selection) properties. The choices array can also contain a\n   Separator.\n-  ``validate``: (Function) Receive the user input and should return true if\n   the value is valid, and an error message (String) otherwise. If false\n   is returned, a default error message is provided.\n-  ``filter``: (Function) Receive the user input and return the filtered\n   value to be used inside the program. The value returned will be added\n   to the Answers hash.\n-  ``when``: (Function, Boolean) Receive the current user answers hash and\n   should return true or false depending on whether or not this question\n   should be asked. The value can also be a simple boolean.\n-  ``pageSize``: (Number) Change the number of lines that will be rendered\n   when using list, rawList, expand or checkbox.\n\nUser Interfaces and Styles\n~~~~~~~~~~~~~~~~~~~~~~~~~~\n\nTODO\n\nWindows Platform\n----------------\n\n**``PyInquirer``** is build on prompt\\_toolkit which is cross platform,\nand everything that you build on top should run fine on both Unix and\nWindows systems. On Windows, it uses a different event loop\n(WaitForMultipleObjects instead of select), and another input and output\nsystem. (Win32 APIs instead of pseudo-terminals and VT100.)\n\nIt\'s worth noting that the implementation is a "best effort of what is\npossible". Both Unix and Windows terminals have their limitations. But\nin general, the Unix experience will still be a little better.\n\nFor Windows, it\'s recommended to use either cmder or conemu.\n\nSupport\n-------\n\nMost of the questions are probably related to using a question type or\nfeature. Please lookup and study the appropriate examples.\n\nIssue on Github TODO link\n\nFor many issues like for example common Python programming issues\nstackoverflow might be a good place to search for an answer. TODO link\n\nContribution\n------------\n\n.. code:: shell\n\n    $ git clone git@github.com:CITGuru/PyInquirer.git\n    $ cd PyInquirer\n    $ python -m venv venv\n    $ source venv/bin/activate\n    $ pip install --upgrade pip\n    $ pip install -r requirements.txt\n    $ pip install -r requirements_dev.txt\n\nWith an environment ready you can add new feature and check everything works\njust fine\n\n.. code:: shell\n\n    $ pytest -sv tests/\n\nThat\'s it, now you can fork a project and submit PR with your change!\n\nCredits\n\n+++++++\n\nContributors\n------------\n\nThis project exists thanks to all the people who contribute!\n\n.. image:: https://opencollective.com/pyinquirer/contributors.svg?width=890&button=false\n\nBackers\n-------\n\nThank you to all our backers! `Become a backer`__.\n\n.. image:: https://opencollective.com/pyinquirer/backers.svg?width=890\n    :target: https://opencollective.com/pyinquirer#backers\n\n__ Backer_\n.. _Backer: https://opencollective.com/pyinquirer#backer\n\nSponsors\n--------\n\nSupport us by becoming a sponsor. Your logo will show up here with a link to your website. `Become a sponsor`__.\n\n.. image:: https://opencollective.com/pyinquirer/sponsor/0/avatar.svg\n    :target: https://opencollective.com/pyinquirer/sponsor/0/website\n\n__ Sponsor_\n.. _Sponsor: https://opencollective.com/pyinquirer#sponsor\n\n\n\nLicense\n-------\n\nCopyright (c) 2018 Oyetoke Toby (twitter: @oyetokeT)\n\nLicensed under the MIT license.\n\n.. |List prompt| image:: https://raw.githubusercontent.com/citguru/PyInquirer/master/docs/images/list-prompt.png\n.. |Expand prompt closed| image:: https://raw.githubusercontent.com/citguru/PyInquirer/master/docs/images/expand-prompt-1.png\n.. |Expand prompt expanded| image:: https://raw.githubusercontent.com/citguru/PyInquirer/master/docs/images/expand-prompt-2.png\n',
    'author': 'Oyetoke Toby',
    'author_email': 'oyetoketoby80@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<3.13',
}


setup(**setup_kwargs)
